@@ -1,29 +1,27 @@
 /* This file is part of gPHPEdit, a GNOME2 PHP Editor.
  
-   Copyright (C) 2003-2005 Andy Jeffries
-      andy@gphpedit.org
+   Copyright (C) 2003, 2004, 2005 Andy Jeffries <andy at gphpedit.org>
+   Copyright (C) 2009 Anoop John <anoop dot john at zyxware.com>
 	  
    For more information or to find the latest release, visit our 
    website at http://www.gphpedit.org/
  
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
- 
-   This program is distributed in the hope that it will be useful, but
-   WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
- 
+   gPHPEdit is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   gPHPEdit is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307, USA.
+   along with gPHPEdit.  If not, see <http://www.gnu.org/licenses/>.
  
-   The GNU General Public License is contained in the file COPYING.*/
-
-
+   The GNU General Public License is contained in the file COPYING.
+*/
+#include <errno.h>
 #include "classbrowser.h"
 #include "main_window.h"
 #include "main_window_callbacks.h"
@@ -191,8 +189,9 @@ void classbrowser_dirlist_add(gchar *dir)
 				if (g_file_test(fullfilename->str, G_FILE_TEST_IS_DIR)) {
 					//classbrowser_dirlist_add(fullfilename->str);
 				}
-				else if (is_php_file_from_filename(fullfilename->str)){
+				else if (is_php_file_from_filename(fullfilename->str)) {
 					classbrowser_filelist_add(fullfilename->str);
+					//debug("File added: %s", fullfilename->str);
 				}
 				g_string_free(fullfilename, TRUE);
 			}
@@ -242,7 +241,7 @@ void classbrowser_filelist_update(void)
 	for(li = filelist; li!= NULL; li = g_slist_next(li)) {
 		file = li->data;
 		if (file) {
-			if (!g_file_exists(file->filename)) {
+			if (!g_file_test(file->filename, G_FILE_TEST_EXISTS)){
 				classbrowser_filelist_remove(file);
 				li = g_slist_remove(filelist, file);
 			}
@@ -542,11 +541,12 @@ void classbrowser_functionlist_add(gchar *classname, gchar *funcname, gchar *fil
 	GtkTreeIter class_iter;
 	GString *function_decl;
 	guint type;
+	
+	//debug("Filename:%s", filename);
 
 	if ((function = classbrowser_functionlist_find(funcname, param_list, filename, classname))) {
 		function->line_number = line_number;
-		function->remove
-		= FALSE;
+		function->remove = FALSE;
 	}
 	else {
 		function = g_malloc0(sizeof(ClassBrowserFunction));
@@ -579,7 +579,7 @@ void classbrowser_functionlist_add(gchar *classname, gchar *funcname, gchar *fil
 			function_decl = g_string_append(function_decl, param_list);
 		}
 		function_decl = g_string_append(function_decl, ")");
-
+		//debug("Filename: %s", filename);
 		gtk_tree_store_set (main_window.classtreestore, &iter,
 		                    NAME_COLUMN, function_decl->str, LINE_NUMBER_COLUMN, line_number, FILENAME_COLUMN, filename, TYPE_COLUMN, type, ID_COLUMN, function->identifierid, -1);
 		g_string_free(function_decl, TRUE);
@@ -628,6 +628,8 @@ void classbrowser_filelist_remove(ClassBrowserFile *file)
 	g_free(file);
 }
 
+//Note: this function can be optimized by not requesting to reparse files on tab change
+//when the parse only selected tab is set - Anoop
 
 void classbrowser_update(void)
 {
@@ -653,19 +655,30 @@ void classbrowser_update(void)
 	classbrowser_dirlist_clear();
 	classbrowser_dirlist_add_shared_source();
 
-	// iterate open files
-	for(li = editors; li!= NULL; li = g_slist_next(li)) {
-		editor = li->data;
-		if (editor) {
-			classbrowser_filelist_add(editor->filename->str);
-			classbrowser_dirlist_add(g_path_get_dirname(editor->filename->str));
+	//if parse only current file is set then add only the file in the current tab
+	if(GTK_TOGGLE_BUTTON (main_window.chkOnlyCurFileFuncs)->active)
+	{
+		//add only if there is a current editor
+		if (main_window.current_editor)
+		{
+			classbrowser_filelist_add(main_window.current_editor->filename->str);
+			g_slist_append(dirlist, g_path_get_dirname(main_window.current_editor->filename->str));
 		}
 	}
+	else
+	{ 
+		// iterate open files
+		for(li = editors; li!= NULL; li = g_slist_next(li)) {
+			editor = li->data;
+			if (editor) {
+				classbrowser_filelist_add(editor->filename->str);
+				classbrowser_dirlist_add(g_path_get_dirname(editor->filename->str));
+			}
+		}
 
-	//classbrowser_dirlist_add(preferences.shared_source_location);
-
+		//classbrowser_dirlist_add(preferences.shared_source_location);
+	}
 	classbrowser_filelist_update();
-
 	classbrowser_start_update();
 
 	while ( (file = classbrowser_filelist_getnext() ) ) {
@@ -674,14 +687,15 @@ void classbrowser_update(void)
 		stat(file->filename, &buf);
 		file->modified_time = buf.st_mtime;
 		classbrowser_parse_file(file->filename);
+		//debug("Parsing %s", file->filename);
 	}
 
 	classbrowser_remove_dead_wood();
 
-	press_event = gtk_signal_connect(GTK_OBJECT(main_window.classtreeview), "button_press_event",
-	                                 GTK_SIGNAL_FUNC(treeview_double_click), NULL);
-	release_event = gtk_signal_connect(GTK_OBJECT(main_window.classtreeview), "button_release_event",
-	                                   GTK_SIGNAL_FUNC(treeview_click_release), NULL);
+	press_event = g_signal_connect(GTK_OBJECT(main_window.classtreeview), "button_press_event",
+	                                 G_CALLBACK(treeview_double_click), NULL);
+	release_event = g_signal_connect(GTK_OBJECT(main_window.classtreeview), "button_release_event",
+	                                   G_CALLBACK(treeview_click_release), NULL);
 }
 
 
@@ -768,9 +782,12 @@ void classbrowser_update_selected_label(gchar *filename, gint line)
 	GString *new_label;
 	ClassBrowserFunction *function;
 	gchar *func_filename;
+	gint num_files;
 
 	filenames = NULL;
+	num_files = 0;
 	for(function_walk = functionlist; function_walk!= NULL; function_walk = g_slist_next(function_walk)) {
+		num_files++;
 		function = function_walk->data;
 		if (function) {
 			func_filename = function->filename;
@@ -780,8 +797,13 @@ void classbrowser_update_selected_label(gchar *filename, gint line)
 			}
 		}
 	}
-
-	new_label = get_differing_part(filenames, filename);
+	if(num_files < 2) {
+		new_label = g_string_new(g_path_get_basename(filename));
+	}
+	else {
+		new_label = get_differing_part(filenames, filename);
+	}
+	//debug("%d :: %s", num_files, new_label);	
 	if (new_label) {
 		new_label = g_string_prepend(new_label, _("FILE: "));
 		g_string_append_printf(new_label, "(%d)", line);
@@ -790,3 +812,37 @@ void classbrowser_update_selected_label(gchar *filename, gint line)
 		g_slist_free(filenames);
 	}
 }
+
+//enable sorting of the list
+void classbrowser_set_sortable(GtkTreeStore *classtreestore)
+{
+	gtk_tree_sortable_set_default_sort_func(GTK_TREE_SORTABLE(classtreestore), 
+		classbrowser_compare_function_names,
+		NULL,NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(classtreestore), 
+		0, classbrowser_compare_function_names, 
+		NULL,NULL);
+	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(classtreestore),
+		0,
+		GTK_SORT_ASCENDING);
+}
+//compare function names of the iter of the gtktreeview
+gint classbrowser_compare_function_names(GtkTreeModel *model,
+										GtkTreeIter *a,
+										GtkTreeIter *b,
+										gpointer user_data)
+{
+	GValue aValue, bValue;
+	gchar *aName, *bName;
+	gint retVal;
+	//gtk_tree_model_get_value(model, a, 0, aValue);
+	//gtk_tree_model_get_value(model, b, 0, bValue);
+	gtk_tree_model_get(model, a, 0, &aName, -1);
+	gtk_tree_model_get(model, b, 0, &bName, -1);
+	//retVal = g_ascii_strcasecmp(g_value_get_string(aValue), g_value_get_string(bValue));
+	retVal = g_ascii_strcasecmp(aName, bName);
+	g_free(aName);
+	g_free(bName);
+	//g_message("* compare values %s and %s; return %d\n", g_value_get_string(&aValue), g_value_get_string(&bValue), retVal);
+	return retVal;
+}
